
#-----------------------------------------------------------------------------
# Add Target(s) to CMake Install for import into other projects
#-----------------------------------------------------------------------------
install (
    EXPORT ${HLJPSS_EXPORTED_TARGETS}
    DESTINATION ${HLJPSS_INSTALL_CMAKE_DIR}/${HLJPSS_PACKAGE}
    FILE ${HLJPSS_PACKAGE}${HDF_PACKAGE_EXT}-targets.cmake
    COMPONENT configinstall
)

#-----------------------------------------------------------------------------
# Export all exported targets to the build tree for use by parent project
#-----------------------------------------------------------------------------
export (
    TARGETS ${HLJPSS_LIBRARIES_TO_EXPORT} ${HLJPSS_LIB_DEPENDENCIES}
    FILE ${HLJPSS_PACKAGE}${HDF_PACKAGE_EXT}-targets.cmake
)

#-----------------------------------------------------------------------------
# Configure the HLJPSS-config.cmake file for the build directory
#-----------------------------------------------------------------------------
set (HLJPSS_INCLUDES_BUILD_TIME
    ${HLJPSS_SRC_DIR}
    ${HLJPSS_BINARY_DIR}
)
set (HLJPSS_VERSION_STRING ${HLJPSS_PACKAGE_VERSION})
set (HLJPSS_VERSION_MAJOR  ${HLJPSS_PACKAGE_VERSION_MAJOR})
set (HLJPSS_VERSION_MINOR  ${HLJPSS_PACKAGE_VERSION_MINOR})

configure_file (
    ${HLJPSS_RESOURCES_DIR}/HLJPSS-config.cmake.build.in 
    ${HLJPSS_BINARY_DIR}/${HLJPSS_PACKAGE}${HDF_PACKAGE_EXT}-config.cmake @ONLY
)

#-----------------------------------------------------------------------------
# Configure the HLJPSS-config.cmake file for the install directory
#-----------------------------------------------------------------------------
  configure_file (
      ${HLJPSS_RESOURCES_DIR}/HLJPSS-config.cmake.install.in
      ${HLJPSS_BINARY_DIR}/CMakeFiles/${HLJPSS_PACKAGE}${HDF_PACKAGE_EXT}-config.cmake @ONLY
  )
  install (
      FILES ${HLJPSS_BINARY_DIR}/CMakeFiles/${HLJPSS_PACKAGE}${HDF_PACKAGE_EXT}-config.cmake
      DESTINATION ${HLJPSS_INSTALL_CMAKE_DIR}/${HLJPSS_PACKAGE}
      COMPONENT configinstall
  )

#-----------------------------------------------------------------------------
# Configure the HLJPSS-config-version .cmake file for the install directory
#-----------------------------------------------------------------------------
  configure_file (
      ${HLJPSS_RESOURCES_DIR}/HLJPSS-config-version.cmake.in
      ${HLJPSS_BINARY_DIR}/CMakeFiles/${HLJPSS_PACKAGE}${HDF_PACKAGE_EXT}-config-version.cmake @ONLY
  )
  install (
      FILES ${HLJPSS_BINARY_DIR}/CMakeFiles/${HLJPSS_PACKAGE}${HDF_PACKAGE_EXT}-config-version.cmake
      DESTINATION ${HLJPSS_INSTALL_CMAKE_DIR}/${HLJPSS_PACKAGE}
      COMPONENT configinstall
  )

#-----------------------------------------------------------------------------
# Check for Installation Utilities
#-----------------------------------------------------------------------------
if (WIN32)
  set (PF_ENV_EXT "(x86)")
  find_program (NSIS_EXECUTABLE NSIS.exe PATHS "$ENV{ProgramFiles}\\NSIS" "$ENV{ProgramFiles${PF_ENV_EXT}}\\NSIS")
  if(NOT CPACK_WIX_ROOT)
    file(TO_CMAKE_PATH "$ENV{WIX}" CPACK_WIX_ROOT)
  endif()
  find_program (WIX_EXECUTABLE candle  PATHS "${CPACK_WIX_ROOT}/bin")
endif (WIN32)

#-----------------------------------------------------------------------------
# Configure the README.txt file for the binary package
#-----------------------------------------------------------------------------
HDF_README_PROPERTIES(TRUE)

#-----------------------------------------------------------------------------
# Configure the COPYING.txt file for the windows binary package
#-----------------------------------------------------------------------------
if (WIN32)
  configure_file (${HLJPSS_SOURCE_DIR}/COPYING ${HLJPSS_BINARY_DIR}/COPYING.txt @ONLY)
endif (WIN32)

#-----------------------------------------------------------------------------
# Add Document File(s) to CMake Install
#-----------------------------------------------------------------------------
install (
    FILES
        ${HLJPSS_SOURCE_DIR}/COPYING
    DESTINATION ${HLJPSS_INSTALL_DATA_DIR}
    COMPONENT hdfdocuments
)
if (EXISTS "${HLJPSS_SOURCE_DIR}/doc" AND IS_DIRECTORY "${HLJPSS_SOURCE_DIR}/doc")
  set (release_files
#      ${HLJPSS_SOURCE_DIR}/doc/USING_HLJPSS_CMake.txt
      ${HLJPSS_SOURCE_DIR}/Using_CMake.txt
  )
#  if (WIN32 AND NOT CYGWIN)
#    set (release_files
#        ${release_files}
#        ${HLJPSS_SOURCE_DIR}/doc/USING_HLJPSS_VS.txt
#    )
#  endif (WIN32 AND NOT CYGWIN)
#  if (HDF_PACK_INSTALL_DOCS)
#    set (release_files
#        ${release_files}
#        ${HLJPSS_SOURCE_DIR}/doc/INSTALL_CMake.txt
#        ${HLJPSS_SOURCE_DIR}/doc/HISTORY.txt
#        ${HLJPSS_SOURCE_DIR}/doc/RELEASE.txt
#    )
#    if (WIN32 AND NOT CYGWIN)
#      set (release_files
#          ${release_files}
#          ${HLJPSS_SOURCE_DIR}/doc/INSTALL_Windows.txt
#      )
#    else (WIN32 AND NOT CYGWIN)
#      set (release_files
#          ${release_files}
#          ${HLJPSS_SOURCE_DIR}/doc/INSTALL_Unix.txt
#      )
#    endif (WIN32 AND NOT CYGWIN)
#  endif (HDF_PACK_INSTALL_DOCS)
  install (
      FILES ${release_files}
      DESTINATION ${HLJPSS_INSTALL_DATA_DIR}
      COMPONENT hdfdocuments
  )
endif (EXISTS "${HLJPSS_SOURCE_DIR}/doc" AND IS_DIRECTORY "${HLJPSS_SOURCE_DIR}/doc")

#-----------------------------------------------------------------------------
# Set the cpack variables
#-----------------------------------------------------------------------------
set (CPACK_PACKAGE_VENDOR "HDF_Group")
set (CPACK_PACKAGE_NAME "${HLJPSS_PACKAGE_NAME}")
set (CPACK_PACKAGE_DESCRIPTION_SUMMARY "HDF5 HLJPSS Installation")
set (CPACK_PACKAGE_DESCRIPTION_FILE "${CMAKE_CURRENT_SOURCE_DIR}/doc/RELEASE.txt")
if (CDASH_LOCAL)
  set (CPACK_PACKAGE_VERSION "${HLJPSS_PACKAGE_VERSION}")
else (CDASH_LOCAL)
  set (CPACK_PACKAGE_VERSION "${HLJPSS_PACKAGE_VERSION_STRING}")
endif (CDASH_LOCAL)
set (CPACK_PACKAGE_VERSION_MAJOR "${HLJPSS_PACKAGE_VERSION_MAJOR}")
set (CPACK_PACKAGE_VERSION_MINOR "${HLJPSS_PACKAGE_VERSION_MINOR}")
set (CPACK_PACKAGE_VERSION_PATCH "")
set (CPACK_RESOURCE_FILE_LICENSE "${CMAKE_CURRENT_SOURCE_DIR}/COPYING")
set (CPACK_RESOURCE_FILE_README "${CMAKE_CURRENT_SOURCE_DIR}/doc/RELEASE.txt")
set (CPACK_PACKAGE_INSTALL_DIRECTORY "${CPACK_PACKAGE_VENDOR}/${CPACK_PACKAGE_NAME}/${CPACK_PACKAGE_VERSION}")
set (CPACK_PACKAGE_RELOCATABLE TRUE)
set (CPACK_PACKAGE_ICON "${HLJPSS_RESOURCES_DIR}/hdf.bmp")

set (CPACK_GENERATOR "TGZ") 
if (WIN32)
  set (CPACK_GENERATOR "ZIP") 
  if (NSIS_EXECUTABLE)    
    list (APPEND CPACK_GENERATOR "NSIS") 
  endif (NSIS_EXECUTABLE)    
  # Installers for 32- vs. 64-bit CMake:
  #  - Root install directory (displayed to end user at installer-run time)
  #  - "NSIS package/display name" (text used in the installer GUI)
  #  - Registry key used to store info about the installation
  set (CPACK_NSIS_PACKAGE_NAME "${HLJPSS_PACKAGE_STRING}")
  if (CMAKE_CL_64)
    set (CPACK_NSIS_INSTALL_ROOT "$PROGRAMFILES64")
    set (CPACK_PACKAGE_INSTALL_REGISTRY_KEY "${CPACK_PACKAGE_NAME}-${CPACK_PACKAGE_VERSION} (Win64)")
  else (CMAKE_CL_64)
    set (CPACK_NSIS_INSTALL_ROOT "$PROGRAMFILES")
    set (CPACK_PACKAGE_INSTALL_REGISTRY_KEY "${CPACK_PACKAGE_NAME}-${CPACK_PACKAGE_VERSION}")
  endif (CMAKE_CL_64)
  # set the install/unistall icon used for the installer itself
  # There is a bug in NSI that does not handle full unix paths properly.
  set (CPACK_NSIS_MUI_ICON "${HDF_RESOURCES_EXT_DIR}\\\\hdf.ico")
  set (CPACK_NSIS_MUI_UNIICON "${HDF_RESOURCES_EXT_DIR}\\\\hdf.ico")
  # set the package header icon for MUI
  set (CPACK_PACKAGE_ICON "${HDF_RESOURCES_EXT_DIR}\\\\hdf.bmp")
  set (CPACK_NSIS_DISPLAY_NAME "${CPACK_NSIS_PACKAGE_NAME}")#, is a conversion library for converting between individual HDF4 and HDF5 objects")
  set (CPACK_PACKAGE_INSTALL_DIRECTORY "${CPACK_PACKAGE_VENDOR}\\\\${CPACK_PACKAGE_NAME}\\\\${CPACK_PACKAGE_VERSION}")
  set (CPACK_MONOLITHIC_INSTALL ON)
  set (CPACK_NSIS_CONTACT "${HLJPSS_PACKAGE_BUGREPORT}")
  set (CPACK_NSIS_MODIFY_PATH ON)
  if (WIX_EXECUTABLE)    
    list (APPEND CPACK_GENERATOR "WIX") 
  endif (WIX_EXECUTABLE)    
#WiX variables
    set (CPACK_WIX_UNINSTALL "1")
# .. variable:: CPACK_WIX_LICENSE_RTF
#  RTF License File
#
#  If CPACK_RESOURCE_FILE_LICENSE has an .rtf extension it is used as-is.
#
#  If CPACK_RESOURCE_FILE_LICENSE has an .txt extension it is implicitly
#  converted to RTF by the WiX Generator.
#  The expected encoding of the .txt file is UTF-8.
#
#  With CPACK_WIX_LICENSE_RTF you can override the license file used by the
#  WiX Generator in case CPACK_RESOURCE_FILE_LICENSE is in an unsupported
#  format or the .txt -> .rtf conversion does not work as expected.
    set (CPACK_RESOURCE_FILE_LICENSE "${HLJPSS_BINARY_DIR}/COPYING.txt")
# .. variable:: CPACK_WIX_PRODUCT_ICON
#  The Icon shown next to the program name in Add/Remove programs.
    set(CPACK_WIX_PRODUCT_ICON "${HDF_RESOURCES_EXT_DIR}\\\\hdf.ico")
#
# .. variable:: CPACK_WIX_UI_BANNER
#
#  The bitmap will appear at the top of all installer pages other than the
#  welcome and completion dialogs.
#
#  If set, this image will replace the default banner image.
#
#  This image must be 493 by 58 pixels.
#
# .. variable:: CPACK_WIX_UI_DIALOG
#
#  Background bitmap used on the welcome and completion dialogs.
#
#  If this variable is set, the installer will replace the default dialog
#  image.
#
#  This image must be 493 by 312 pixels.
#
elseif (APPLE)
  list (APPEND CPACK_GENERATOR "DragNDrop") 
  set (CPACK_COMPONENTS_ALL_IN_ONE_PACKAGE ON)
  set (CPACK_PACKAGING_INSTALL_PREFIX "/${CPACK_PACKAGE_INSTALL_DIRECTORY}")
  set (CPACK_PACKAGE_ICON "${HDF_RESOURCES_EXT_DIR}/hdf.icns")

  if (HDF_PACK_MACOSX_BUNDLE)
    list (APPEND CPACK_GENERATOR "Bundle")
    set (CPACK_BUNDLE_NAME "${HLJPSS_PACKAGE_STRING}")
    set (CPACK_BUNDLE_LOCATION "/")    # make sure CMAKE_INSTALL_PREFIX ends in /
    set (CMAKE_INSTALL_PREFIX "/${CPACK_BUNDLE_NAME}.framework/Versions/${CPACK_PACKAGE_VERSION}/${CPACK_PACKAGE_NAME}/")
    set (CPACK_BUNDLE_ICON "${HDF_RESOURCES_EXT_DIR}/hdf.icns")
    set (CPACK_BUNDLE_PLIST "${HLJPSS_BINARY_DIR}/CMakeFiles/Info.plist")
    set (CPACK_APPLE_GUI_INFO_STRING "HLJPSS (H4toH5 conversion) Software Library and Utilities")
    set (CPACK_APPLE_GUI_COPYRIGHT "Copyright © 2006-2014 by The HDF Group. All rights reserved.")
    set (CPACK_SHORT_VERSION_STRING "${CPACK_PACKAGE_VERSION}")
    set (CPACK_APPLE_GUI_BUNDLE_NAME "${HLJPSS_PACKAGE_STRING}")
    set (CPACK_APPLE_GUI_VERSION_STRING "${CPACK_PACKAGE_VERSION_STRING}")
    set (CPACK_APPLE_GUI_SHORT_VERSION_STRING "${CPACK_PACKAGE_VERSION}")
    #-----------------------------------------------------------------------------
    # Configure the Info.plist file for the install bundle
    #-----------------------------------------------------------------------------
    configure_file (
        ${HDF_RESOURCES_EXT_DIR}/CPack.Info.plist.in
        ${HLJPSS_BINARY_DIR}/CMakeFiles/Info.plist @ONLY
    )
    configure_file (
        ${HLJPSS_RESOURCES_DIR}/PkgInfo.in
        ${HLJPSS_BINARY_DIR}/CMakeFiles/PkgInfo @ONLY
    )
    configure_file (
        ${HDF_RESOURCES_EXT_DIR}/version.plist.in
        ${HLJPSS_BINARY_DIR}/CMakeFiles/version.plist @ONLY
    )
    install (
        FILES ${HLJPSS_BINARY_DIR}/CMakeFiles/PkgInfo
              ${HLJPSS_BINARY_DIR}/CMakeFiles/version.plist
        DESTINATION ..
    )
  endif (HDF_PACK_MACOSX_BUNDLE)
else (WIN32)
  list (APPEND CPACK_GENERATOR "STGZ") 
  set (CPACK_PACKAGING_INSTALL_PREFIX "/${CPACK_PACKAGE_INSTALL_DIRECTORY}")
  set (CPACK_COMPONENTS_ALL_IN_ONE_PACKAGE ON)

  set (CPACK_DEBIAN_PACKAGE_SECTION "Libraries")
  set (CPACK_DEBIAN_PACKAGE_MAINTAINER "${HLJPSS_PACKAGE_BUGREPORT}")

#    list (APPEND CPACK_GENERATOR "RPM") 
  set (CPACK_RPM_PACKAGE_RELEASE "1")
  set (CPACK_RPM_COMPONENT_INSTALL ON)
  set (CPACK_RPM_PACKAGE_RELOCATABLE ON)
  set (CPACK_RPM_PACKAGE_GROUP "Development/Tools")
  set (CPACK_RPM_PACKAGE_LICENSE "BSD-style")
  set (CPACK_RPM_PACKAGE_URL "${HLJPSS_PACKAGE_URL}")
  set (CPACK_RPM_PRE_INSTALL_SCRIPT_FILE "/sbin/ldconfig")
  set (CPACK_RPM_PRE_UNINSTALL_SCRIPT_FILE "/sbin/ldconfig")
  set (CPACK_RPM_POST_INSTALL_SCRIPT_FILE "/sbin/ldconfig")
  set (CPACK_RPM_POST_UNINSTALL_SCRIPT_FILE "/sbin/ldconfig")
  set (CPACK_STRIP_FILES "${HLJPSS_LIBRARIES_TO_EXPORT};${HLJPSS_APPS_TO_EXPORT};${EXTERNAL_LIBRARY_LIST}")
endif (WIN32)

# By default, do not warn when built on machines using only VS Express:
if (NOT DEFINED CMAKE_INSTALL_SYSTEM_RUNTIME_LIBS_NO_WARNINGS)
  set (CMAKE_INSTALL_SYSTEM_RUNTIME_LIBS_NO_WARNINGS ON)
endif (NOT DEFINED CMAKE_INSTALL_SYSTEM_RUNTIME_LIBS_NO_WARNINGS)
include (InstallRequiredSystemLibraries)

set (CPACK_INSTALL_CMAKE_PROJECTS "${HLJPSS_BINARY_DIR};HLJPSS;ALL;/")
  
if (HDF_PACKAGE_EXTLIBS)
  if (HDF_ALLOW_EXTERNAL_SUPPORT MATCHES "SVN" OR HDF_ALLOW_EXTERNAL_SUPPORT MATCHES "TGZ")
    if (HDF5_FOUND AND HDF5_USE_EXTERNAL)
      set (CPACK_INSTALL_CMAKE_PROJECTS "${CPACK_INSTALL_CMAKE_PROJECTS};${HDF5_INCLUDE_DIR_GEN};HDF5;libraries;/")
      set (CPACK_INSTALL_CMAKE_PROJECTS "${CPACK_INSTALL_CMAKE_PROJECTS};${HDF5_INCLUDE_DIR_GEN};HDF5;headers;/")
      set (CPACK_INSTALL_CMAKE_PROJECTS "${CPACK_INSTALL_CMAKE_PROJECTS};${HDF5_INCLUDE_DIR_GEN};HDF5;configinstall;/")
    endif (HDF5_FOUND AND HDF5_USE_EXTERNAL)
  endif (HDF_ALLOW_EXTERNAL_SUPPORT MATCHES "SVN" OR HDF_ALLOW_EXTERNAL_SUPPORT MATCHES "TGZ")
endif (HDF_PACKAGE_EXTLIBS)
  
include (CPack)

#-----------------------------------------------------------------------------
# Now list the cpack commands
#-----------------------------------------------------------------------------
CPACK_ADD_COMPONENT (libraries 
    DISPLAY_NAME "HLJPSS Libraries"
    GROUP Runtime
)
CPACK_ADD_COMPONENT (headers 
    DISPLAY_NAME "HLJPSS Headers" 
    DEPENDS libraries
    GROUP Development
)
CPACK_ADD_COMPONENT (hdfdocuments 
    DISPLAY_NAME "HLJPSS Documents"
    GROUP Documents
)
CPACK_ADD_COMPONENT (configinstall 
    DISPLAY_NAME "HLJPSS CMake files" 
    DEPENDS libraries
    GROUP Development
)
  
if (HDF_BUILD_FORTRAN)
  CPACK_ADD_COMPONENT (fortlibraries 
      DISPLAY_NAME "HLJPSS Fortran Libraries" 
      DEPENDS libraries
      GROUP Runtime
  )
  CPACK_ADD_COMPONENT (fortheaders 
      DISPLAY_NAME "HLJPSS Fortran Headers" 
      DEPENDS fortlibraries
      GROUP Development
  )
endif (HDF_BUILD_FORTRAN)
